@@ -3,7 +3,7 @@ use strict;
 use warnings;
 package YAML::PP::Parser;
 
-our $VERSION = '0.026_002'; # TRIAL VERSION
+our $VERSION = '0.027_001'; # TRIAL VERSION
 
 use constant TRACE => $ENV{YAML_PP_TRACE} ? 1 : 0;
 use constant DEBUG => ($ENV{YAML_PP_DEBUG} || $ENV{YAML_PP_TRACE}) ? 1 : 0;
@@ -1280,6 +1280,18 @@ sub cb_empty_flowmap_value {
     $self->scalar_event($info);
 }
 
+sub cb_empty_flowseq_comma {
+    my ($self, $token) = @_;
+    $self->cb_empty_flowmap_value($token);
+    $self->cb_flow_comma;
+}
+
+sub cb_empty_flowseq_end {
+    my ($self, $token) = @_;
+    $self->cb_empty_flowmap_value($token);
+    $self->cb_end_flowseq;
+}
+
 sub cb_insert_map_alias {
     my ($self, $res) = @_;
     my $stack = $self->event_stack;
